@@ -88,7 +88,7 @@ sub log_line {
     $fmt =~ s{
         (?:
          \%\{(.+?)\}([a-z]) |
-         \%(?:[<>])?([a-z\%])
+         \%(?:[<>])?([a-zA-Z\%])
         )
     }{ $1 ? $block_handler->($1, $2) : $char_handler->($3) }egx;
 
